
**spotlib** | Library for use with Amazon EC2 Spot Prices
-----------------------------------------------------------

PACKAGE: spotlib

``spotlib``: reusable library for retrieval, conversion, and storage 
              of Amazon EC2 spot price history data (json format).

Includes:
* class for setting historical window for data
* class for spot price data retrieval and transformation
